### Creating sticky notes has never been easier.

[![GitHub license](https://img.shields.io/github/license/GrgBls/Noty.svg)](https://github.com/GrgBls/Noty)


#### :heavy_exclamation_mark: This program will not work with Python2, it only works with Python3

<a href="https://cloud.githubusercontent.com/assets/24195309/26754364/e3bcdbce-4879-11e7-924b-82e9dc434b50.gif"><img src="https://cloud.githubusercontent.com/assets/24195309/26754364/e3bcdbce-4879-11e7-924b-82e9dc434b50.gif" title="Noty"/></a>




## Installation
---

    # Clone the repository
    $ git clone https://github.com/GrgBls/noty.git

    # Move into noty folder.
    $ cd noty

    # Install noty
    $ sudo python3 setup.py install

    # Run it
    $ noty

    # You are now ready to use it!

## How to:

    # Run it
    $ noty

    #Type your notes
    $ Remember to buy milk.

    #You are now ready to use it.


## Contributing instructions.

1. Fork the repository.
2. Create your branch: `git checkout -b my-branch`
3. Commit your changes: `git commit -am 'Fixed something.'`
4. Push to the branch: `git push origin my-branch`
5. Submit a pull request.



### install_requires
Python3  

tkinter

setuptools

---
